@@ -179,6 +179,16 @@ impl<T: BitWrite<E>, E: Endianness> BitWrite<E> for Arc<T> {
     }
 }
 
+impl<T: BitWrite<E>, E: Endianness> BitWrite<E> for Vec<T> {
+    #[inline]
+    fn write(&self, stream: &mut BitWriteStream<E>) -> Result<()> {
+        for item in self {
+            stream.write(item)?;
+        }
+        Ok(())
+    }
+}
+
 macro_rules! impl_write_tuple {
     ($($i:tt: $type:ident),*) => {
         impl<'a, E: Endianness, $($type: BitWrite<E>),*> BitWrite<E> for ($($type),*) {
